# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/widgets/account.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_AccountWidget(object):
    def setupUi(self, AccountWidget):
        AccountWidget.setObjectName("AccountWidget")
        AccountWidget.resize(615, 274)
        AccountWidget.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(AccountWidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.QRCodeAddressLabel = QtWidgets.QLabel(AccountWidget)
        self.QRCodeAddressLabel.setMaximumSize(QtCore.QSize(100, 100))
        self.QRCodeAddressLabel.setBaseSize(QtCore.QSize(200, 0))
        self.QRCodeAddressLabel.setText("")
        self.QRCodeAddressLabel.setPixmap(QtGui.QPixmap(":/images/safe"))
        self.QRCodeAddressLabel.setScaledContents(True)
        self.QRCodeAddressLabel.setObjectName("QRCodeAddressLabel")
        self.horizontalLayout.addWidget(self.QRCodeAddressLabel)
        self.balanceLabel = QtWidgets.QLabel(AccountWidget)
        font = QtGui.QFont()
        font.setPointSize(40)
        self.balanceLabel.setFont(font)
        self.balanceLabel.setObjectName("balanceLabel")
        self.horizontalLayout.addWidget(self.balanceLabel)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.refreshButton = QtWidgets.QPushButton(AccountWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refreshButton.sizePolicy().hasHeightForWidth())
        self.refreshButton.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/refresh_icon"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshButton.setIcon(icon)
        self.refreshButton.setObjectName("refreshButton")
        self.verticalLayout.addWidget(self.refreshButton, 0, QtCore.Qt.AlignLeft)
        self.transferToButton = QtWidgets.QPushButton(AccountWidget)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/money-recive-svgrepo-com.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.transferToButton.setIcon(icon1)
        self.transferToButton.setIconSize(QtCore.QSize(32, 32))
        self.transferToButton.setObjectName("transferToButton")
        self.verticalLayout.addWidget(self.transferToButton)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setContentsMargins(6, -1, 0, -1)
        self.formLayout_2.setObjectName("formLayout_2")
        self.lockStatusIcon = QtWidgets.QLabel(AccountWidget)
        self.lockStatusIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.lockStatusIcon.setText("")
        self.lockStatusIcon.setPixmap(QtGui.QPixmap(":/images/locked_cartoon_400x400.png"))
        self.lockStatusIcon.setScaledContents(True)
        self.lockStatusIcon.setObjectName("lockStatusIcon")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.lockStatusIcon)
        self.addressValueLabel = QtWidgets.QLabel(AccountWidget)
        self.addressValueLabel.setText("")
        self.addressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.addressValueLabel.setObjectName("addressValueLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.addressValueLabel)
        self.identityLabel = QtWidgets.QLabel(AccountWidget)
        self.identityLabel.setMaximumSize(QtCore.QSize(16, 20))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.identityLabel.setFont(font)
        self.identityLabel.setText("")
        self.identityLabel.setPixmap(QtGui.QPixmap(":/icons/member_icon"))
        self.identityLabel.setScaledContents(True)
        self.identityLabel.setObjectName("identityLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.identityLabel)
        self.identityValueLabel = QtWidgets.QLabel(AccountWidget)
        self.identityValueLabel.setObjectName("identityValueLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.identityValueLabel)
        self.nameLabel = QtWidgets.QLabel(AccountWidget)
        self.nameLabel.setText("")
        self.nameLabel.setObjectName("nameLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.nameLabel)
        self.derivationIconLabel = QtWidgets.QLabel(AccountWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.derivationIconLabel.sizePolicy().hasHeightForWidth())
        self.derivationIconLabel.setSizePolicy(sizePolicy)
        self.derivationIconLabel.setMaximumSize(QtCore.QSize(16, 20))
        self.derivationIconLabel.setText("")
        self.derivationIconLabel.setPixmap(QtGui.QPixmap(":/icons/wot_icon"))
        self.derivationIconLabel.setScaledContents(True)
        self.derivationIconLabel.setObjectName("derivationIconLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.derivationIconLabel)
        self.derivationValueLabel = QtWidgets.QLabel(AccountWidget)
        self.derivationValueLabel.setText("")
        self.derivationValueLabel.setObjectName("derivationValueLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.derivationValueLabel)
        self.smithLabel = QtWidgets.QLabel(AccountWidget)
        self.smithLabel.setMaximumSize(QtCore.QSize(16, 20))
        self.smithLabel.setText("")
        self.smithLabel.setPixmap(QtGui.QPixmap(":/icons/smith"))
        self.smithLabel.setScaledContents(True)
        self.smithLabel.setObjectName("smithLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.smithLabel)
        self.smithValuelabel = QtWidgets.QLabel(AccountWidget)
        self.smithValuelabel.setObjectName("smithValuelabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.smithValuelabel)
        self.verticalLayout_2.addLayout(self.formLayout_2)
        self.errorLabel = QtWidgets.QLabel(AccountWidget)
        self.errorLabel.setStyleSheet("color: red")
        self.errorLabel.setText("")
        self.errorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.errorLabel.setObjectName("errorLabel")
        self.verticalLayout_2.addWidget(self.errorLabel)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem1)

        self.retranslateUi(AccountWidget)
        QtCore.QMetaObject.connectSlotsByName(AccountWidget)

    def retranslateUi(self, AccountWidget):
        #  _translate = QtCore.QCoreApplication.translate
        AccountWidget.setWindowTitle(_("Account"))
        self.balanceLabel.setText(_("0"))
        self.refreshButton.setText(_("Refresh"))
        self.transferToButton.setText(_("Transfer to"))
        self.identityValueLabel.setText(_("None"))
        self.smithValuelabel.setText(_("None"))
import tikka.slots.pyqt.resources.icons.index_rc
