# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tikka/slots/pyqt/resources/gui/windows/transfer.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_TransferDialog(object):
    def setupUi(self, TransferDialog):
        TransferDialog.setObjectName("TransferDialog")
        TransferDialog.resize(865, 256)
        self.gridLayout = QtWidgets.QGridLayout(TransferDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.amountLabel = QtWidgets.QLabel(TransferDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.amountLabel.setFont(font)
        self.amountLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.amountLabel.setObjectName("amountLabel")
        self.gridLayout.addWidget(self.amountLabel, 5, 0, 1, 1)
        self.sendButton = QtWidgets.QPushButton(TransferDialog)
        self.sendButton.setObjectName("sendButton")
        self.gridLayout.addWidget(self.sendButton, 6, 3, 1, 1)
        self.senderNameOrAddressLineEdit = QtWidgets.QLineEdit(TransferDialog)
        self.senderNameOrAddressLineEdit.setClearButtonEnabled(True)
        self.senderNameOrAddressLineEdit.setObjectName("senderNameOrAddressLineEdit")
        self.gridLayout.addWidget(self.senderNameOrAddressLineEdit, 0, 1, 1, 4)
        self.recipientLabel = QtWidgets.QLabel(TransferDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.recipientLabel.setFont(font)
        self.recipientLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.recipientLabel.setObjectName("recipientLabel")
        self.gridLayout.addWidget(self.recipientLabel, 2, 0, 1, 1)
        self.recipientNameOrAddressLineEdit = QtWidgets.QLineEdit(TransferDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.recipientNameOrAddressLineEdit.sizePolicy().hasHeightForWidth())
        self.recipientNameOrAddressLineEdit.setSizePolicy(sizePolicy)
        self.recipientNameOrAddressLineEdit.setClearButtonEnabled(True)
        self.recipientNameOrAddressLineEdit.setObjectName("recipientNameOrAddressLineEdit")
        self.gridLayout.addWidget(self.recipientNameOrAddressLineEdit, 2, 1, 1, 4)
        self.recipientBalanceValueLabel = QtWidgets.QLabel(TransferDialog)
        self.recipientBalanceValueLabel.setText("")
        self.recipientBalanceValueLabel.setObjectName("recipientBalanceValueLabel")
        self.gridLayout.addWidget(self.recipientBalanceValueLabel, 2, 8, 1, 1)
        self.amountUnitComboBox = QtWidgets.QComboBox(TransferDialog)
        self.amountUnitComboBox.setObjectName("amountUnitComboBox")
        self.gridLayout.addWidget(self.amountUnitComboBox, 5, 2, 1, 1)
        self.amountDoubleSpinBox = QtWidgets.QDoubleSpinBox(TransferDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.amountDoubleSpinBox.sizePolicy().hasHeightForWidth())
        self.amountDoubleSpinBox.setSizePolicy(sizePolicy)
        self.amountDoubleSpinBox.setMaximum(999999999999.99)
        self.amountDoubleSpinBox.setObjectName("amountDoubleSpinBox")
        self.gridLayout.addWidget(self.amountDoubleSpinBox, 5, 1, 1, 1)
        self.feesButton = QtWidgets.QPushButton(TransferDialog)
        self.feesButton.setObjectName("feesButton")
        self.gridLayout.addWidget(self.feesButton, 5, 3, 1, 1)
        self.senderLabel = QtWidgets.QLabel(TransferDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.senderLabel.setFont(font)
        self.senderLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.senderLabel.setObjectName("senderLabel")
        self.gridLayout.addWidget(self.senderLabel, 0, 0, 1, 1)
        self.recipientNameOrAddressValueLabel = QtWidgets.QLabel(TransferDialog)
        font = QtGui.QFont()
        font.setItalic(True)
        self.recipientNameOrAddressValueLabel.setFont(font)
        self.recipientNameOrAddressValueLabel.setText("")
        self.recipientNameOrAddressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.recipientNameOrAddressValueLabel.setObjectName("recipientNameOrAddressValueLabel")
        self.gridLayout.addWidget(self.recipientNameOrAddressValueLabel, 3, 1, 1, 4)
        self.errorLabel = QtWidgets.QLabel(TransferDialog)
        self.errorLabel.setStyleSheet("")
        self.errorLabel.setText("")
        self.errorLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.errorLabel.setObjectName("errorLabel")
        self.gridLayout.addWidget(self.errorLabel, 7, 1, 1, 4)
        self.buttonBox = QtWidgets.QDialogButtonBox(TransferDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonBox.sizePolicy().hasHeightForWidth())
        self.buttonBox.setSizePolicy(sizePolicy)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 7, 8, 1, 1, QtCore.Qt.AlignHCenter)
        self.feesLabel = QtWidgets.QLabel(TransferDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.feesLabel.setFont(font)
        self.feesLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.feesLabel.setObjectName("feesLabel")
        self.gridLayout.addWidget(self.feesLabel, 6, 0, 1, 1)
        self.feesValueLabel = QtWidgets.QLabel(TransferDialog)
        self.feesValueLabel.setText("")
        self.feesValueLabel.setObjectName("feesValueLabel")
        self.gridLayout.addWidget(self.feesValueLabel, 6, 1, 1, 1)
        self.senderBalanceValueLabel = QtWidgets.QLabel(TransferDialog)
        self.senderBalanceValueLabel.setText("")
        self.senderBalanceValueLabel.setObjectName("senderBalanceValueLabel")
        self.gridLayout.addWidget(self.senderBalanceValueLabel, 0, 8, 1, 1)
        self.senderNameOrAddressValueLabel = QtWidgets.QLabel(TransferDialog)
        font = QtGui.QFont()
        font.setItalic(True)
        self.senderNameOrAddressValueLabel.setFont(font)
        self.senderNameOrAddressValueLabel.setText("")
        self.senderNameOrAddressValueLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.senderNameOrAddressValueLabel.setObjectName("senderNameOrAddressValueLabel")
        self.gridLayout.addWidget(self.senderNameOrAddressValueLabel, 1, 1, 1, 4)
        self.loaderIconLabel = QtWidgets.QLabel(TransferDialog)
        self.loaderIconLabel.setEnabled(True)
        self.loaderIconLabel.setMaximumSize(QtCore.QSize(16, 16))
        self.loaderIconLabel.setScaledContents(True)
        self.loaderIconLabel.setObjectName("loaderIconLabel")
        self.gridLayout.addWidget(self.loaderIconLabel, 6, 4, 1, 1)
        self.commentLabel = QtWidgets.QLabel(TransferDialog)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.commentLabel.setFont(font)
        self.commentLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.commentLabel.setObjectName("commentLabel")
        self.gridLayout.addWidget(self.commentLabel, 4, 0, 1, 1)
        self.commentLineEdit = QtWidgets.QLineEdit(TransferDialog)
        self.commentLineEdit.setText("")
        self.commentLineEdit.setObjectName("commentLineEdit")
        self.gridLayout.addWidget(self.commentLineEdit, 4, 1, 1, 4)

        self.retranslateUi(TransferDialog)
        QtCore.QMetaObject.connectSlotsByName(TransferDialog)
        TransferDialog.setTabOrder(self.recipientNameOrAddressLineEdit, self.amountDoubleSpinBox)
        TransferDialog.setTabOrder(self.amountDoubleSpinBox, self.amountUnitComboBox)
        TransferDialog.setTabOrder(self.amountUnitComboBox, self.feesButton)
        TransferDialog.setTabOrder(self.feesButton, self.sendButton)

    def retranslateUi(self, TransferDialog):
        #  _translate = QtCore.QCoreApplication.translate
        TransferDialog.setWindowTitle(_("Transfer"))
        self.amountLabel.setText(_("Amount"))
        self.sendButton.setText(_("Send"))
        self.senderNameOrAddressLineEdit.setPlaceholderText(_("Name or address"))
        self.recipientLabel.setText(_("Recipient"))
        self.recipientNameOrAddressLineEdit.setPlaceholderText(_("Name or address"))
        self.feesButton.setText(_("Fees"))
        self.senderLabel.setText(_("Sender"))
        self.feesLabel.setText(_("Fees"))
        self.commentLabel.setText(_("Comment"))
import tikka.slots.pyqt.resources.icons.index_rc
